@@ -5,6 +5,7 @@ import openpyxl
 import os
 import time
 
+from openpyxl.styles import Alignment, Font
 from ..proto.proto import Commit
 
 head = {
@@ -15,7 +16,10 @@ head = {
     'E': Commit.DATE,
     'F': Commit.COMMIT,
     'G': Commit.MESSAGE,
-    'H': Commit.URL
+    'H': Commit.URL,
+    'I': Commit.CHANGE,
+    'J': Commit.COMMITTER,
+    'K': Commit.TOPIC
 }
 
 
@@ -46,14 +50,17 @@ class Printer(object):
     def _txt(self, data, name):
         def _txt_helper(data, out):
             global head
-            out.write(u'%s%s: %s\n' % (' '*3, head['A'], data[head['A']]))
-            out.write(u'%s%s: %s\n' % (' '*3, head['B'], data[head['B']]))
-            out.write(u'%s%s: %s\n' % (' '*1, head['C'], data[head['C']]))
-            out.write(u'%s%s: %s\n' % (' '*1, head['D'], data[head['D']]))
-            out.write(u'%s%s: %s\n' % (' '*3, head['E'], data[head['E']]))
-            out.write(u'%s%s: %s\n' % (' '*1, head['F'], data[head['F']]))
-            out.write(u'%s%s: %s\n' % (' '*0, head['G'], data[head['G']]))
-            out.write(u'%s%s: %s\n' % (' '*0, head['H'], data[head['H']]))
+            out.write(u'%s%s: %s\n' % (' '*5, head['A'], data[head['A']]))
+            out.write(u'%s%s: %s\n' % (' '*5, head['B'], data[head['B']]))
+            out.write(u'%s%s: %s\n' % (' '*3, head['C'], data[head['C']]))
+            out.write(u'%s%s: %s\n' % (' '*3, head['D'], data[head['D']]))
+            out.write(u'%s%s: %s\n' % (' '*5, head['E'], data[head['E']]))
+            out.write(u'%s%s: %s\n' % (' '*3, head['F'], data[head['F']]))
+            out.write(u'%s%s: %s\n' % (' '*2, head['G'], data[head['G']]))
+            out.write(u'%s%s: %s\n' % (' '*6, head['H'], data[head['H']]))
+            out.write(u'%s%s: %s\n' % (' '*3, head['I'], data[head['I']]))
+            out.write(u'%s%s: %s\n' % (' '*0, head['J'], data[head['J']]))
+            out.write(u'%s%s: %s\n' % (' '*4, head['K'], data[head['K']]))
             out.write('\n')
 
         with open(name, 'w', encoding='utf8') as f:
@@ -62,12 +69,26 @@ class Printer(object):
                 _txt_helper(item, f)
 
     def _xlsx(self, data, name):
+        def _styling_head(sheet):
+            for item in head.keys():
+                sheet[item+'1'].alignment = Alignment(horizontal='center', shrink_to_fit=True, vertical='center')
+                sheet[item+'1'].font = Font(bold=True, name='Calibri')
+            sheet.freeze_panes = sheet['B2']
+
+        def _styling_data(sheet, rows):
+            for key in head.keys():
+                for row in range(rows):
+                    sheet[key+str(row+2)].alignment = Alignment(vertical='center')
+                    sheet[key+str(row+2)].font = Font(bold=False, name='Calibri')
+
         wb = openpyxl.Workbook()
         ws = wb.active
         ws.title = time.strftime('%Y-%m-%d', time.localtime(time.time()))
         ws.append([head[key].upper() for key in sorted(head.keys())])
         for item in data:
             ws.append([item[head[key]] for key in sorted(head.keys())])
+        _styling_head(ws)
+        _styling_data(ws, len(data))
         wb.save(filename=name)
 
     def run(self, data, name):
